@@ -1,6 +1,6 @@
 ;;; cider-completion.el --- Smart REPL-powered code completion -*- lexical-binding: t -*-
 
-;; Copyright © 2013-2025 Bozhidar Batsov, Artur Malabarba and CIDER contributors
+;; Copyright © 2013-2026 Bozhidar Batsov, Artur Malabarba and CIDER contributors
 ;;
 ;; Author: Bozhidar Batsov <bozhidar@batsov.dev>
 ;;         Artur Malabarba <bruce.connor.am@gmail.com>
@@ -104,8 +104,8 @@ backend, and ABBREVIATION is a short form of that type."
 (defcustom cider-completion-annotations-include-ns 'unqualified
   "Controls passing of namespaces to `cider-annotate-completion-function'.
 
-When set to 'always, the candidate's namespace will always be passed if it
-is available.  When set to 'unqualified, the namespace will only be passed
+When set to `always', the candidate's namespace will always be passed if it
+is available.  When set to `unqualified', the namespace will only be passed
 if the candidate is not namespace-qualified."
   :type '(choice (const always)
                  (const unqualified)
