@@ -25,8 +25,6 @@
 
 ;;; Code:
 
-(require 'map)
-(require 'seq)
 (require 'subr-x)
 
 (require 'spinner)
@@ -210,7 +208,7 @@ list."
   :type '(alist :key-type character
                 :value-type (list
                              (string :tag "command name")
-                             (choice (string :tag "display name") nil)))
+                             (choice (string :tag "display name") (const nil))))
   :package-version '(cider . "0.24.0"))
 
 (defun cider--debug-format-locals-list (locals)
@@ -230,8 +228,8 @@ Each element of LOCALS should be a list of at least two elements."
 (defun cider--debug-propertize-prompt-commands ()
   "In-place format the command display names for the `cider-debug-prompt' overlay."
   (mapc (lambda (spec)
-          (cl-destructuring-bind (char _cmd disp-name) spec
-            (when-let* ((pos (cl-position char disp-name)))
+          (pcase-let ((`(,char ,_cmd ,disp-name) spec))
+            (when-let* ((pos (seq-position disp-name char)))
               (put-text-property pos (1+ pos) 'face 'cider-debug-prompt-face disp-name))))
         cider-debug-prompt-commands))
 
@@ -240,14 +238,14 @@ Each element of LOCALS should be a list of at least two elements."
   ;; Force `default' face, otherwise the overlay "inherits" the face of the text
   ;; after it.
   (format (propertize "%s\n" 'face 'default)
-          (cl-reduce
+          (seq-reduce
            (lambda (prompt spec)
-             (cl-destructuring-bind (_char cmd disp) spec
-               (if (and disp (cl-find cmd commands :test 'string=))
+             (pcase-let ((`(,_char ,cmd ,disp) spec))
+               (if (and disp (seq-find (lambda (c) (string= cmd c)) commands))
                    (concat prompt " " disp)
                  prompt)))
            cider-debug-prompt-commands
-           :initial-value "")))
+           "")))
 
 (defvar-local cider--debug-prompt-overlay nil)
 
@@ -507,7 +505,7 @@ REASON is a keyword describing why this buffer was necessary."
 COORDINATES is a list of integers that specify how to navigate into the
 sexp that is after point when this function is called.
 
-As an example, a COORDINATES list of '(1 0 2) means:
+As an example, a COORDINATES list of (1 0 2) means:
   - enter next sexp then `forward-sexp' once,
   - enter next sexp,
   - enter next sexp then `forward-sexp' twice.
