@@ -64,8 +64,8 @@
 
 (defcustom cider-show-error-buffer t
   "Control the popup behavior of cider stacktraces.
-The following values are possible t or 'always, 'except-in-repl,
-'only-in-repl.  Any other value, including nil, will cause the stacktrace
+The following values are possible t or `always', `except-in-repl',
+`only-in-repl'.  Any other value, including nil, will cause the stacktrace
 not to be automatically shown.
 
 Irrespective of the value of this variable, the `cider-error-buffer' is
@@ -88,7 +88,7 @@ in order to void its effect."
 (defcustom cider-auto-jump-to-error t
   "Control the cursor jump behavior in compilation error buffer.
 When non-nil automatically jump to error location during interactive
-compilation.  When set to 'errors-only, don't jump to warnings.
+compilation.  When set to `errors-only', don't jump to warnings.
 When set to nil, don't jump at all."
   :type '(choice (const :tag "always" t)
                  (const errors-only)
@@ -120,7 +120,7 @@ Only applies when the *cider-inspect* buffer is currently visible."
 (defcustom cider-save-file-on-load 'prompt
   "Controls whether to prompt to save the file when loading a buffer.
 If nil, files are not saved.
-If 'prompt, the user is prompted to save the file if it's been modified.
+If `prompt', the user is prompted to save the file if it's been modified.
 If t, save the file without confirmation."
   :type '(choice (const :tag "Prompt to save the file if it's been modified" prompt)
                  (const :tag "Don't save the file" nil)
@@ -221,7 +221,7 @@ Returns the position at which PROPERTY was found, or nil if not found."
 _ARG and _RESET are ignored, as there is only ever one compilation error.
 They exist for compatibility with `next-error'."
   (interactive)
-  (cl-labels ((goto-next-note-boundary
+  (cl-flet ((goto-next-note-boundary
                ()
                (let ((p (or (cider-find-property 'cider-note-p)
                             (cider-find-property 'cider-note-p t))))
@@ -336,7 +336,7 @@ If you wish phases to be ignored, set this variable to nil instead.
 
 You can learn more about Clojure's error phases at:
 https://clojure.org/reference/repl_and_main#_at_repl"
-  :type 'list
+  :type '(repeat string)
   :group 'cider
   :package-version '(cider . "0.18.0"))
 
@@ -470,20 +470,6 @@ Show error overlay in BUFFER if needed."
 \"Syntax error compiling at (src/workspace_service.clj:227:3).\"
 \"Unexpected error (ClassCastException) macroexpanding defmulti at (src/haystack/parser.cljc:21:1).\"")
 
-(defconst cider--clojure-execution-error
-  `(sequence
-    (or "Error reading eval result "   ; phase = :read-eval-result
-        "Error printing return value " ; phase = :print-eval-result
-        "Execution error ")            ; phase = :execution
-    (minimal-match (zero-or-more anything)) ; optional class, eg. (ArithmeticException)
-    ,cider--clojure-1.10-location))
-
-(defconst cider--clojure-spec-execution-error
-  `(sequence
-    "Execution error - invalid arguments to "
-    (minimal-match (one-or-more anything))
-    " "
-    ,cider--clojure-1.10-location))
 
 (defconst cider-module-info-regexp
   (rx " ("
@@ -1316,8 +1302,7 @@ command `cider-debug-defun-at-point'."
   (let ((inline-debug (eq 16 (car-safe debug-it))))
     (when debug-it
       (when (cider-clojurescript-major-mode-p)
-        (when (y-or-n-p (concat "The debugger doesn't support ClojureScript yet, and we need help with that."
-                                "  \nWould you like to read the Feature Request?"))
+        (when (y-or-n-p "The debugger doesn't support ClojureScript yet, and we need help with that.  \nWould you like to read the Feature Request?")
           (browse-url "https://github.com/clojure-emacs/cider/issues/1416"))
         (user-error "The debugger does not support ClojureScript"))
       (when inline-debug
