@@ -54,7 +54,7 @@ The page size can be also changed interactively within the inspector."
 
 (defcustom cider-inspector-max-atom-length 150
   "Default max length of nested atoms before they are truncated.
-'Atom' here means any collection member that satisfies (complement coll?).
+Atom here means any collection member that satisfies (complement coll?).
 The max length can be also changed interactively within the inspector."
   :type '(integer :tag "Max atom length" 150)
   :package-version '(cider . "1.1.0"))
@@ -71,8 +71,6 @@ The max depth can be also changed interactively within the inspector."
   :type '(integer :tag "Max nested collection depth" 5)
   :package-version '(cider . "1.14.0"))
 
-(defvar cider-inspector-spacious-collections nil
-  "Controls whether the inspector renders values in collections spaciously.")
 
 (defcustom cider-inspector-fill-frame nil
   "Controls whether the CIDER inspector window fills its frame."
@@ -601,7 +599,7 @@ from stack), `:next-inspectable' (move point to next inspectable object)."
           ((and (consp el) (eq (car el) :newline))
            (insert "\n"))
           ((and (consp el) (eq (car el) :value))
-           (cider-inspector-render-value (cadr el) (cl-caddr el)))
+           (cider-inspector-render-value (cadr el) (caddr el)))
           (t (message "Unrecognized inspector object: %s" el))))
 
   ;; Java-related headers indicate that the next elements to be rendered
@@ -623,15 +621,16 @@ from stack), `:next-inspectable' (move point to next inspectable object)."
 
 (defun cider-find-inspectable-object (direction limit)
   "Find the next/previous inspectable object.
-DIRECTION can be either 'next or 'prev.
+DIRECTION can be either `next' or `prev'.
 LIMIT is the maximum or minimum position in the current buffer.
 
 Return a list of two values: If an object could be found, the
 starting position of the found object and T is returned;
 otherwise LIMIT and NIL is returned."
-  (let ((finder (cl-ecase direction
-                  (next 'next-single-property-change)
-                  (prev 'previous-single-property-change))))
+  (let ((finder (pcase direction
+                  ('next 'next-single-property-change)
+                  ('prev 'previous-single-property-change)
+                  (_ (error "Invalid direction: %s" direction)))))
     (let ((prop nil) (curpos (point)))
       (while (and (not prop) (not (= curpos limit)))
         (let ((newpos (funcall finder curpos 'cider-value-idx nil limit)))
